# Changelog

## [0.2.1a1](https://github.com/OpenVoiceOS/ovos-PHAL/tree/0.2.1a1) (2024-09-11)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-PHAL/compare/0.2.0...0.2.1a1)

**Merged pull requests:**

- fix:update\_mk2\_requirements [\#42](https://github.com/OpenVoiceOS/ovos-PHAL/pull/42) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
